==> local-booter-22.3.0-720.113-sources.jar: com/xebialabs/xlplatform/synthetic/xml/XmlInputHintSpecification.java <==
package com.xebialabs.xlplatform.synthetic.xml;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import org.w3c.dom.Element;

import com.xebialabs.deployit.plugin.api.reflect.InputHintValue;
import com.xebialabs.deployit.plugin.api.reflect.Type;
import com.xebialabs.xlplatform.synthetic.InputHintSpecification;
import com.xebialabs.xlplatform.synthetic.ValidationRuleSpecification;

import static com.xebialabs.deployit.plugin.api.reflect.InputHintValue.inputHintValue;

public class XmlInputHintSpecification extends XmlElement implements InputHintSpecification {

    public XmlInputHintSpecification(Element element) {
        super(element);
    }

    @Override
    public List<InputHintValue> getValues() {
        List<InputHintValue> inputHintValues = new ArrayList<>();
        XmlUtils.forEach(XmlUtils.childByName(element, "values"::equals), valuesElement ->
            XmlUtils.forEach(XmlUtils.childByName(valuesElement, "value"::equals), valueElement -> {
                String value = valueElement.getTextContent();
                String label = XmlUtils.getOptionalStringAttribute(valueElement, "label", value);
                inputHintValues.add(inputHintValue(value, label));
            })
        );
        return inputHintValues;
    }

    @Override
    public List<ValidationRuleSpecification> getValidationRules() {
        return new XmlPropertySpecification(element).getValidationRules();
    }

    @Override
    public Optional<String> getPrompt() {
        return XmlUtils.getOptionalTextOfChild(element, "prompt");
    }

    @Override
    public Optional<String> getCopyFromProperty() {
        return XmlUtils.getOptionalTextOfChild(element, "copy-from-property");
    }

    @Override
    public Optional<Type> getReferencedType() {
        return Optional.ofNullable(XmlUtils.getOptionalTypeAttribute(element, "referenced-type"));
    }

    @Override
    public Optional<String> getMethodRef() {
        return XmlUtils.getOptionalString(element, "method-ref");
    }

    @Override
    public Optional<Boolean> getDynamicLookup() {
        return XmlUtils.getOptionalBoolean(element, "dynamic-lookup");
    }
}

==> local-booter-23.1.0-404.1515-sources.jar: com/xebialabs/xlplatform/synthetic/xml/XmlInputHintSpecification.java <==
package com.xebialabs.xlplatform.synthetic.xml;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import com.xebialabs.xlplatform.synthetic.TypeName;
import org.w3c.dom.Element;

import com.xebialabs.deployit.plugin.api.reflect.InputHintValue;
import com.xebialabs.xlplatform.synthetic.InputHintSpecification;
import com.xebialabs.xlplatform.synthetic.ValidationRuleSpecification;

import static com.xebialabs.deployit.plugin.api.reflect.InputHintValue.inputHintValue;

public class XmlInputHintSpecification extends XmlElement implements InputHintSpecification {

    public XmlInputHintSpecification(Element element) {
        super(element);
    }

    @Override
    public List<InputHintValue> getValues() {
        List<InputHintValue> inputHintValues = new ArrayList<>();
        XmlUtils.forEach(XmlUtils.childByName(element, "values"::equals), valuesElement ->
            XmlUtils.forEach(XmlUtils.childByName(valuesElement, "value"::equals), valueElement -> {
                String value = valueElement.getTextContent();
                String label = XmlUtils.getOptionalStringAttribute(valueElement, "label", value);
                inputHintValues.add(inputHintValue(value, label));
            })
        );
        return inputHintValues;
    }

    @Override
    public List<ValidationRuleSpecification> getValidationRules() {
        return new XmlPropertySpecification(element).getValidationRules();
    }

    @Override
    public Optional<String> getPrompt() {
        return XmlUtils.getOptionalTextOfChild(element, "prompt");
    }

    @Override
    public Optional<String> getCopyFromProperty() {
        return XmlUtils.getOptionalTextOfChild(element, "copy-from-property");
    }

    @Override
    public Optional<TypeName> getReferencedType() {
        return Optional.ofNullable(XmlUtils.getOptionalTypeAttribute(element, "referenced-type"));
    }

    @Override
    public Optional<String> getMethodRef() {
        return XmlUtils.getOptionalString(element, "method-ref");
    }

    @Override
    public Optional<Boolean> getDynamicLookup() {
        return XmlUtils.getOptionalBoolean(element, "dynamic-lookup");
    }
}
